@@ -6,7 +6,9 @@ A node and widget for placing data onto a grid (or not).
 
 from enum import Enum, unique
 
-from typing import Tuple, Dict, Any, List, Union, Optional, Sequence
+from typing import Tuple, Dict, Any, List, Optional, Sequence, cast
+
+from typing_extensions import TypedDict
 
 from plottr import QtGui, Signal, Slot, QtWidgets
 from .node import Node, NodeWidget, updateOption, updateGuiFromNode
@@ -18,10 +20,6 @@ __author__ = 'Wolfgang Pfaff'
 __license__ = 'MIT'
 
 
-#: Type for additional options when specifying the shape
-SpecShapeType = Dict[str, Tuple[Union[str, int], ...]]
-
-
 @unique
 class GridOption(Enum):
     """Options for how to grid data."""
@@ -38,6 +36,14 @@ class GridOption(Enum):
     #: read the shape from DataSet Metadata (if available)
     metadataShape = 3
 
+class _WidgetDict(TypedDict):
+    name: QtWidgets.QComboBox
+    shape: QtWidgets.QSpinBox
+
+#: Type for additional options when specifying the shape
+class SpecShapeType(TypedDict):
+    order: Tuple[str, ...]
+    shape: Tuple[int, ...]
 
 class ShapeSpecificationWidget(QtWidgets.QWidget):
     """A widget that allows the user to specify a grid shape.
@@ -55,7 +61,7 @@ class ShapeSpecificationWidget(QtWidgets.QWidget):
         super().__init__(parent)
 
         self._axes: List[str] = []
-        self._widgets: Dict[int, Dict[str, QtWidgets.QWidget]] = {}
+        self._widgets: Dict[int, _WidgetDict] = {}
         self._processChanges = True
 
         layout = QtWidgets.QFormLayout()
@@ -82,7 +88,7 @@ class ShapeSpecificationWidget(QtWidgets.QWidget):
             'name': nameWidget,
             'shape': dimLenWidget,
         }
-        self.layout().insertRow(idx, nameWidget, dimLenWidget)
+        cast(QtWidgets.QFormLayout, self.layout()).insertRow(idx, nameWidget, dimLenWidget)
 
         nameWidget.currentTextChanged.connect(
             lambda x: self._processAxisChange(idx, x)
@@ -96,11 +102,11 @@ class ShapeSpecificationWidget(QtWidgets.QWidget):
         """
         if axes != self._axes:
             self._axes = axes
-
-            for i in range(self.layout().rowCount() - 1):
+            layout = cast(QtWidgets.QFormLayout, self.layout())
+            for i in range(layout.rowCount() - 1):
                 self._widgets[i]['name'].deleteLater()
                 self._widgets[i]['shape'].deleteLater()
-                self.layout().removeRow(0)
+                layout.removeRow(0)
 
             self._widgets = {}
 
@@ -133,7 +139,7 @@ class ShapeSpecificationWidget(QtWidgets.QWidget):
             self._widgets[prevIdx]['name'].setCurrentText(unused[0])
             self._processChanges = True
 
-    def setShape(self, shape: Dict[str, Tuple[Union[str, int], ...]]) -> None:
+    def setShape(self, shape: SpecShapeType) -> None:
         """ Set the shape, will be reflected in the values set in the widgets.
 
         :param shape: A dictionary with keys `order` and `shape`. The value
@@ -148,7 +154,7 @@ class ShapeSpecificationWidget(QtWidgets.QWidget):
                 self._widgets[i]['shape'].setValue(s)
             self._processChanges = True
 
-    def getShape(self) -> Dict[str, Tuple[Union[str, int], ...]]:
+    def getShape(self) -> SpecShapeType:
         """get the currently specified shape.
 
         :returns: a dictionary with keys `order` and `shape`.
@@ -220,7 +226,7 @@ class GridOptionWidget(QtWidgets.QWidget):
         self.buttons[GridOption.noGrid].setChecked(True)
         self.enableShapeEdit(False)
 
-    def getGrid(self) -> Tuple[GridOption, Dict[str, Any]]:
+    def getGrid(self) -> Tuple[GridOption, Optional[SpecShapeType]]:
         """Get grid option from the current widget selections
 
         :returns: the grid specification, and the options that go with it.
@@ -230,7 +236,7 @@ class GridOptionWidget(QtWidgets.QWidget):
         """
         activeBtn = self.btnGroup.checkedButton()
         activeId = self.btnGroup.id(activeBtn)
-        opts = {}
+        opts: Optional[SpecShapeType] = None
 
         if GridOption(activeId) == GridOption.specifyShape:
             opts = self.shapeSpec.getShape()
@@ -281,7 +287,7 @@ class GridOptionWidget(QtWidgets.QWidget):
     def shapeSpecified(self) -> None:
         self.signalGridOption(self.getGrid())
 
-    def signalGridOption(self, grid: Tuple[GridOption, Dict[str, Any]]) -> None:
+    def signalGridOption(self, grid: Tuple[GridOption, Optional[SpecShapeType]]) -> None:
         self.optionSelected.emit(grid)
 
     def setAxes(self, axes: List[str]) -> None:
@@ -338,7 +344,7 @@ class DataGridderNodeWidget(NodeWidget):
         self.widget.setShape(shape)
 
 
-class DataGridder(Node):
+class DataGridder(Node[DataGridderNodeWidget]):
     """
     A node that can put data onto or off a grid.
     Has one property: :attr:`grid`. Its possible values are governed by a main option,
